@@ -10,7 +10,7 @@ my $StartingOf = {
     'message' => ['The following message to <', 'An error occurred while trying to deliver the mail '],
     'rfc822'  => ['content-type: message/rfc822'],
 };
-my $ReFailures = { 'expired' => qr/Delivery expired/ };
+my $MessagesOf = { 'expired' => ['Delivery expired'] };
 
 # X-SenderID: Sendmail Sender-ID Filter v1.0.0 nijo.example.jp p7V3i843003008
 # X-Original-To: 000001321defbd2a-788e31c8-2be1-422f-a8d4-cf7765cc9ed7-000000@email-bounces.amazonses.com
@@ -206,9 +206,9 @@ sub scan {
             $e->{'status'} = $pseudostatus if length $pseudostatus;
         }
 
-        SESSION: for my $r ( keys %$ReFailures ) {
+        SESSION: for my $r ( keys %$MessagesOf ) {
             # Verify each regular expression of session errors
-            next unless $e->{'diagnosis'} =~ $ReFailures->{ $r };
+            next unless grep { index($e->{'diagnosis'}, $_) > -1 } @{ $MessagesOf->{ $r } };
             $e->{'reason'} = $r;
             last;
         }
