@@ -10,7 +10,7 @@ my $StartingOf = {
     'rfc822'  => ['--- The header of the original message is following'],
     'error'   => ['For the following reason:'],
 };
-my $ReFailures = { 'mesgtoobig' => qr/Mail size limit exceeded/, };
+my $MessagesOf = { 'mesgtoobig' => ['Mail size limit exceeded'] };
 
 # X-UI-Out-Filterresults: unknown:0;
 # sub headerlist  { return ['X-UI-Out-Filterresults'] }
@@ -114,9 +114,9 @@ sub scan {
         $e->{'diagnosis'} =~ s/\A$StartingOf->{'error'}->[0]//g;
         $e->{'diagnosis'} =  Sisimai::String->sweep($e->{'diagnosis'});
 
-        SESSION: for my $r ( keys %$ReFailures ) {
+        SESSION: for my $r ( keys %$MessagesOf ) {
             # Verify each regular expression of session errors
-            next unless $e->{'diagnosis'} =~ $ReFailures->{ $r };
+            next unless grep { index($e->{'diagnosis'}, $_) > -1 } @{ $MessagesOf->{ $r } };
             $e->{'reason'} = $r;
             last;
         }
