@@ -2,7 +2,6 @@ package Sisimai::Message;
 use feature ':5.10';
 use strict;
 use warnings;
-use Module::Load '';
 use Class::Accessor::Lite;
 
 my $rwaccessors = [
@@ -43,7 +42,7 @@ sub new {
 
     } else {
         # Unsupported value in "input"
-        warn sprintf(qq| ***warning: Unsupported value in "input": %s|, $input);
+        warn ' ***warning: Unsupported value in "input": '.$input;
         return undef;
     }
 
@@ -53,11 +52,8 @@ sub new {
         return undef;
     }
 
-    eval { Module::Load::load $child };
-    if( $@ ) {
-        warn sprintf(" ***warning: Failed to load module: %s", $@);
-        return undef;
-    }
+    (my $modulepath = $child) =~ s|::|/|g; 
+    require $modulepath.'.pm';
 
     my $methodargv = {
         'data'  => $email,
@@ -67,7 +63,7 @@ sub new {
     my $datasource = undef;
     my $mesgobject = undef;
 
-    for my $e ( 'load', 'order' ) {
+    for my $e ('load', 'order') {
         # Order of MTA modules
         next unless exists $argvs->{ $e };
         next unless ref $argvs->{ $e } eq 'ARRAY';
@@ -155,7 +151,7 @@ in the argument of this method as an array reference like following code:
                         'load' => ['Your::Custom::MTA::Module']
                   );
 
-Beggining from v4.19.0, `hook` argument is available to callback user defined
+Beginning from v4.19.0, `hook` argument is available to callback user defined
 method like the following codes:
 
     my $cmethod = sub {
@@ -173,7 +169,7 @@ method like the following codes:
         }
 
         # Message body of the bounced email
-        if( $argv->{'message'} =~ m/^X-Postfix-Queue-ID:\s*(.+)$/m ) {
+        if( $argv->{'message'} =~ /^X-Postfix-Queue-ID:\s*(.+)$/m ) {
             $data->{'queue-id'} = $1;
         }
 
@@ -231,7 +227,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
