@@ -13,22 +13,17 @@ sub match {
     # @since v4.0.0
     my $class = shift;
     my $argv1 = shift // return undef;
-    my $regex = qr{(?>
-         improper[ ]use[ ]of[ ]8-bit[ ]data[ ]in[ ]message[ ]header
-        |message[ ](?:
-             header[ ]size,[ ]or[ ]recipient[ ]list,[ ]exceeds[ ]policy[ ]limit
-            |mime[ ]complexity[ ]exceeds[ ]the[ ]policy[ ]maximum
-            )
-        |routing[ ]loop[ ]detected[ ][-][-][ ]too[ ]many[ ]received:[ ]headers
-        |this[ ]message[ ]contains?[ ](?:
-             invalid[ ]mime[ ]headers
-            |improperly[-]formatted[ ]binary[ ]content
-            |text[ ]that[ ]uses[ ]unnecessary[ ]base64[ ]encoding
-            )
-        )
-    }x;
+    my $index = [
+        'improper use of 8-bit data in message header',
+        'message header size, or recipient list, exceeds policy limit',
+        'message mime complexity exceeds the policy maximum',
+        'routing loop detected -- too many received: headers',
+        'this message contain invalid mime headers',
+        'this message contain improperly-formatted binary content',
+        'this message contain text that uses unnecessary base64 encoding',
+    ];
 
-    return 1 if $argv1 =~ $regex;
+    return 1 if grep { rindex($argv1, $_) > -1 } @$index;
     return 0;
 }
 
@@ -105,7 +100,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
