@@ -69,7 +69,7 @@ sub match {
         |rejected(?:
              :[ ]spamassassin[ ]score[ ]
             |[ ]by[ ].+[ ][(]spam[)]
-            |[ ]due[ ]to[ ]spam[ ]content
+            |[ ]due[ ]to[ ]spam[ ](?:classification|content)
             )
         |rejecting[ ]banned[ ]content 
         |related[ ]to[ ]content[ ]with[ ]spam[-]like[ ]characteristics
