@@ -13,28 +13,23 @@ sub match {
     # @since v4.1.26
     my $class = shift;
     my $argv1 = shift // return undef;
-    my $regex = qr{(?>
-         All[ ]available[ ]IPs[ ]are[ ]at[ ]maximum[ ]connection[ ]limit    # SendGrid
-        |connection[ ]rate[ ]limit[ ]exceeded
-        |domain[ ].+[ ]has[ ]exceeded[ ]the[ ]max[ ]emails[ ]per[ ]hour[ ].+[ ]allowed
-        |no[ ]IPs[ ]available[ ][-][ ].+[ ]exceeds[ ]per[-]domain[ ]connection[ ]limit[ ]for
-        |Throttling[ ]failure:[ ](?:
-             Daily[ ]message[ ]quota[ ]exceeded
-            |Maximum[ ]sending[ ]rate[ ]exceeded
-            )
-        |Too[ ]many[ ](?:
-             connections
-            |connections[ ]from[ ]your[ ]host[.]    # Microsoft
-            |concurrent[ ]SMTP[ ]connections        # Microsoft
-            |errors[ ]from[ ]your[ ]IP              # Free.fr
-            |SMTP[ ]sessions[ ]for[ ]this[ ]host    # Sendmail(daemon.c)
-            )
-        |Trop[ ]de[ ]connexions,[ ].+[A-Z]{3}.+104
-        |We[ ]have[ ]already[ ]made[ ]numerous[ ]attempts[ ]to[ ]deliver[ ]this[ ]message
-        )
-    }xi;
+    my $index = [
+        'all available ips are at maximum connection limit',    # SendGrid
+        'connection rate limit exceeded',
+        'exceeds per-domain connection limit for',
+        'has exceeded the max emails per hour ',
+        'throttling failure: daily message quota exceeded',
+        'throttling failure: maximum sending rate exceeded',
+        'too many connections',
+        'too many connections from your host.', # Microsoft
+        'too many concurrent smtp connections', # Microsoft
+        'too many errors from your ip',         # Free.fr
+        'too many smtp sessions for this host', # Sendmail(daemon.c)
+        'trop de connexions, ',
+        'we have already made numerous attempts to deliver this message',
+    ];
 
-    return 1 if $argv1 =~ $regex;
+    return 1 if grep { rindex($argv1, $_) > -1 } @$index;
     return 0;
 }
 
@@ -49,24 +44,12 @@ sub true {
     my $argvs = shift // return undef;
 
     return undef unless ref $argvs eq 'Sisimai::Data';
-    return 1 if $argvs->reason eq __PACKAGE__->text;
+    return 1 if $argvs->reason eq 'toomanyconn';
 
     require Sisimai::SMTP::Status;
-    my $statuscode = $argvs->deliverystatus // '';
-    my $diagnostic = $argvs->diagnosticcode // '';
-    my $tempreason = Sisimai::SMTP::Status->name($statuscode);
-    my $reasontext = __PACKAGE__->text;
-    my $v = 0;
-
-    if( $tempreason eq $reasontext ) {
-        # Delivery status code points "toomanyconn".
-        $v = 1;
-
-    } else {
-        # Matched with a pattern in this class
-        $v = 1 if __PACKAGE__->match($diagnostic);
-    }
-    return $v;
+    return 1 if Sisimai::SMTP::Status->name($argvs->deliverystatus) eq 'toomanyconn';
+    return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
+    return 0;
 }
 
 1;
@@ -120,7 +103,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
@@ -128,3 +111,4 @@ This software is distributed under The BSD 2-Clause License.
 
 =cut
 
+
