@@ -2,13 +2,13 @@ package Sisimai::Rhost;
 use feature ':5.10';
 use strict;
 use warnings;
-use Module::Load '';
 
 my $RhostClass = {
     qr/\Aaspmx[.]l[.]google[.]com\z/                 => 'GoogleApps',
     qr/[.](?:prod|protection)[.]outlook[.]com\z/     => 'ExchangeOnline',
     qr/\A(?:smtp|mailstore1)[.]secureserver[.]net\z/ => 'GoDaddy',
     qr/\b(?:laposte[.]net|orange[.]fr)\z/            => 'FrancePTT',
+    qr/[.](?:ezweb[.]ne[.]jp|au[.]com)\z/            => 'KDDI',
 };
 
 sub list {
@@ -45,11 +45,11 @@ sub get {
     my $argvs = shift // return undef;
 
     return undef unless ref $argvs eq 'Sisimai::Data';
-    return $argvs->reason if length $argvs->reason;
 
     my $reasontext = '';
     my $remotehost = lc $argvs->rhost;
     my $rhostclass = '';
+    my $modulepath = '';
 
     for my $e ( keys %$RhostClass ) {
         # Try to match with each key of $RhostClass
@@ -59,7 +59,8 @@ sub get {
     }
 
     return undef unless length $rhostclass;
-    Module::Load::load($rhostclass);
+    ($modulepath = $rhostclass) =~ s|::|/|g; 
+    require $modulepath.'.pm';
     $reasontext = $rhostclass->get($argvs);
 
     return $reasontext;
